--[[

	BaleCounter.lua -  this script adds a bale counter to a baler
	
	@author:	Robert 'Gate' Hostens
	@date:		2012/5/5
	@version:	v1.0
	@history:	v1.0 -	initial implementation

	note: original script by unknown author
	
]]


--[[
	Bale counter global specialization for farming simulator 2013
	
	Author: Gate <gate@was-bored.com>
	Date: 2013/04/27
]]


BaleCounter = {};

local bc_directory = g_currentModDirectory;

function BaleCounter.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Baler, specializations);
end;


function BaleCounter:load(xmlFile)
	self.currentBales = 0;
	self.totalBales = 0;
	
	self.xPos = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.BaleCounter#posX"), 0.5029);
	self.yPos = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.BaleCounter#posY"), 0.05238);

	self.hud = Overlay:new("BaleCounter", Utils.getFilename("Textures/BaleCounter_hud.png", bc_directory), self.xPos, self.yPos, 0.2371, 0.039525);
	
	self.dirtyFlag = self:getNextDirtyFlag();
	self.isDirty = true;
end;

function BaleCounter:delete()
end;

function BaleCounter.dropBale(self, baleIndex)
	if self.currentBales ~= nil and self.totalBales ~= nil then
		self.currentBales = self.currentBales + 1;
		self.totalBales   = self.totalBales + 1;
		self.isDirty      = true;
	end;
end;

function BaleCounter:mouseEvent(posX, posY, isDown, isUp, button)
end;

function BaleCounter:keyEvent(unicode, sym, modifier, isDown)
end;

function BaleCounter:update(dt)
end;

function BaleCounter:updateTick(dt)
	if self.isDirty then
		self:raiseDirtyFlags(self.dirtyFlag);
		self.isDirty = false;
	end;
end;

function BaleCounter:draw()
	local x = self.xPos + 0.102;
	local y = self.yPos;
	
	self.hud:render();
	
	setTextAlignment(RenderText.ALIGN_RIGHT);
	setTextBold(true);	
	
	setTextColor(0, 0, 0, 1);
    renderText(self.xPos+0.102,          self.yPos+0.008, 0.022, tostring(self.currentBales));
	renderText(self.xPos+0.102+0.2371/2, self.yPos+0.008, 0.022, tostring(self.totalBales));
	
	setTextColor(0,0.95,0,1);
	renderText(self.xPos+0.102,          self.yPos+0.010, 0.023, tostring(self.currentBales));
	setTextColor(0.95,0,0,1);
	renderText(self.xPos+0.102+0.2371/2, self.yPos+0.010, 0.023, tostring(self.totalBales));
	
	setTextColor(1,1,1,1);
	setTextBold(false);	
	setTextAlignment(RenderText.ALIGN_LEFT);
end;

function BaleCounter:readStream(streamId, connection)
	self.currentBales = streamReadFloat32(streamId);
	self.totalBales   = streamReadFloat32(streamId);
end;

function BaleCounter:writeStream(streamId, connection)
	streamWriteFloat32(streamId, self.currentBales);
	streamWriteFloat32(streamId, self.totalBales);
end;

function BaleCounter:readUpdateStream(streamId, timestamp, connection)
    if connection:getIsServer() then
        if streamReadBool(streamId) then
			self.BaleCounter.sessionHectars = streamReadFloat32(streamId);
			self.totalBalesHectars = streamReadFloat32(streamId);
        end;
    end;
end;

function BaleCounter:writeUpdateStream(streamId, connection, dirtyMask)
    if not connection:getIsServer() then
        if streamWriteBool(streamId, bitAND(dirtyMask, self.dirtyFlag) ~= 0) then
			streamWriteFloat32(streamId, self.currentBales);
			streamWriteFloat32(streamId, self.totalBales);
        end;
    end;
end;

function BaleCounter:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if (not resetVehicles) then
		self.totalBales = Utils.getNoNil(getXMLInt(xmlFile, key.."#totalBales"), 0);
	end;
	
	return BaseMission.VEHICLE_LOAD_OK;
end;

function BaleCounter:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'totalBales="'..tostring(self.totalBales)..'"';
	local nodes = nil;
	
	return attributes, nodes;
end;

Baler.dropBale = Utils.appendedFunction(BaleCounter.dropBale, Baler.dropBale);